summaryrefslogtreecommitdiff
path: root/src/defaults.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/defaults.cpp')
-rw-r--r--src/defaults.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/defaults.cpp b/src/defaults.cpp
index f95e72c7b..8fc7c028e 100644
--- a/src/defaults.cpp
+++ b/src/defaults.cpp
@@ -1,9 +1,9 @@
/*
* The ManaPlus Client
* Copyright (C) 2010 The Mana Developers
* Copyright (C) 2011-2019 The ManaPlus Developers
*
* This file is part of The ManaPlus Client.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
@@ -495,7 +495,7 @@ void setBrandingDefaults(Configuration &cfg)
DefaultsData &configData = cfg.getDefaultValues();
AddDEF("wallpapersPath", "");
AddDEF("wallpapersFile", "");
- AddDEF("appName", "ManaPlus");
+ AddDEF("appName", "ManaVerse");
AddDEF("appIcon", "icons/manaplus");
AddDEF("loginMusic", "keprohm.ogg");
AddDEF("defaultServer", "");
@@ -507,7 +507,7 @@ void setBrandingDefaults(Configuration &cfg)
"https://www.manaplus.germantmw.de/manaplus/serverlist.xml");
AddDEF("onlineServerFile", "serverlistplus.xml");
AddDEF("appShort", "mana");
- AddDEF("screenshots", "ManaPlus");
+ AddDEF("screenshots", "ManaVerse");
AddDEF("defaultUpdateHost", "");
AddDEF("helpPath", "");
AddDEF("tagsPath", "");
@@ -1,9 +1,9 @@
/*
- * The ManaPlus Client
+ * The ManaVerse Client
* Copyright (C) 2010 The Mana Developers
* Copyright (C) 2011-2019 The ManaPlus Developers
@@ -1,9 +1,9 @@
* Copyright (C) 2011-2019 The ManaPlus Developers
*
- * This file is part of The ManaPlus Client.
+ * This file is part of The ManaVerse Client.
*
* This program is free software; you can redistribute it and/or modify